SelectionModal class

Inheritance

Constructors

SelectionModal({bool filterable = true, List dataSource = const [], String title = 'Please select one or more option(s)', List values = const [], String textField = 'text', String valueField = 'value', int? maxLength, String? maxLengthText, Color? buttonBarColor, String? cancelButtonText, IconData? cancelButtonIcon, Color? cancelButtonColor, Color? cancelButtonTextColor, String? saveButtonText, IconData? saveButtonIcon, Color? saveButtonColor, Color? saveButtonTextColor, String? clearButtonText, IconData? clearButtonIcon, Color? clearButtonColor, Color? clearButtonTextColor, String? deleteButtonTooltipText, IconData? deleteIcon, Color? deleteIconColor, Color? selectedOptionsBoxColor, String? selectedOptionsInfoText, Color? selectedOptionsInfoTextColor, IconData? checkedIcon, IconData? uncheckedIcon, Color? checkBoxColor, Color? searchBoxColor, String? searchBoxHintText, Color? searchBoxFillColor, Color? searchBoxTextColor, IconData? searchBoxIcon, String? searchBoxToolTipText})

Properties

buttonBarColor → Color?
final
cancelButtonColor → Color?
final
cancelButtonIcon → IconData?
final
cancelButtonText → String?
final
cancelButtonTextColor → Color?
final
checkBoxColor → Color?
final
checkedIcon → IconData?
final
clearButtonColor → Color?
final
clearButtonIcon → IconData?
final
clearButtonText → String?
final
clearButtonTextColor → Color?
final
dataSource → List
final
deleteButtonTooltipText → String?
final
deleteIcon → IconData?
final
deleteIconColor → Color?
final
filterable → bool
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxLength → int?
final
maxLengthText → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saveButtonColor → Color?
final
saveButtonIcon → IconData?
final
saveButtonText → String?
final
saveButtonTextColor → Color?
final
searchBoxColor → Color?
final
searchBoxFillColor → Color?
final
searchBoxHintText → String?
final
searchBoxIcon → IconData?
final
searchBoxTextColor → Color?
final
searchBoxToolTipText → String?
final
selectedOptionsBoxColor → Color?
final
selectedOptionsInfoText → String?
final
selectedOptionsInfoTextColor → Color?
final
textField → String
final
title → String
final
uncheckedIcon → IconData?
final
valueField → String
final
values → List
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _SelectionModalState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited